@@ -1,10 +1,12 @@
 import torch
 from torch import nn
-from TTS.tts.layers.speedy_speech.decoder import Decoder
-from TTS.tts.layers.speedy_speech.duration_predictor import DurationPredictor
-from TTS.tts.layers.speedy_speech.encoder import Encoder, PositionalEncoding
-from TTS.tts.utils.generic_utils import sequence_mask
+
+from TTS.tts.layers.feed_forward.decoder import Decoder
+from TTS.tts.layers.feed_forward.duration_predictor import DurationPredictor
+from TTS.tts.layers.feed_forward.encoder import Encoder
+from TTS.tts.layers.generic.pos_encoding import PositionalEncoding
 from TTS.tts.layers.glow_tts.monotonic_align import generate_path
+from TTS.tts.utils.generic_utils import sequence_mask
 
 
 class SpeedySpeech(nn.Module):
@@ -33,42 +35,37 @@ class SpeedySpeech(nn.Module):
         external_c (bool, optional): enable external speaker embeddings. Defaults to False.
         c_in_channels (int, optional): number of channels in speaker embedding vectors. Defaults to 0.
     """
+
     # pylint: disable=dangerous-default-value
 
     def __init__(
-            self,
-            num_chars,
-            out_channels,
-            hidden_channels,
-            positional_encoding=True,
-            length_scale=1,
-            encoder_type='residual_conv_bn',
-            encoder_params={
-                "kernel_size": 4,
-                "dilations": 4 * [1, 2, 4] + [1],
-                "num_conv_blocks": 2,
-                "num_res_blocks": 13
-            },
-            decoder_type='residual_conv_bn',
-            decoder_params={
-                "kernel_size": 4,
-                "dilations": 4 * [1, 2, 4, 8] + [1],
-                "num_conv_blocks": 2,
-                "num_res_blocks": 17
-            },
-            num_speakers=0,
-            external_c=False,
-            c_in_channels=0):
+        self,
+        num_chars,
+        out_channels,
+        hidden_channels,
+        positional_encoding=True,
+        length_scale=1,
+        encoder_type="residual_conv_bn",
+        encoder_params={"kernel_size": 4, "dilations": 4 * [1, 2, 4] + [1], "num_conv_blocks": 2, "num_res_blocks": 13},
+        decoder_type="residual_conv_bn",
+        decoder_params={
+            "kernel_size": 4,
+            "dilations": 4 * [1, 2, 4, 8] + [1],
+            "num_conv_blocks": 2,
+            "num_res_blocks": 17,
+        },
+        num_speakers=0,
+        external_c=False,
+        c_in_channels=0,
+    ):
 
         super().__init__()
         self.length_scale = float(length_scale) if isinstance(length_scale, int) else length_scale
         self.emb = nn.Embedding(num_chars, hidden_channels)
-        self.encoder = Encoder(hidden_channels, hidden_channels, encoder_type,
-                               encoder_params, c_in_channels)
+        self.encoder = Encoder(hidden_channels, hidden_channels, encoder_type, encoder_params, c_in_channels)
         if positional_encoding:
             self.pos_encoder = PositionalEncoding(hidden_channels)
-        self.decoder = Decoder(out_channels, hidden_channels,
-                               decoder_type, decoder_params)
+        self.decoder = Decoder(out_channels, hidden_channels, decoder_type, decoder_params)
         self.duration_predictor = DurationPredictor(hidden_channels + c_in_channels)
 
         if num_speakers > 1 and not external_c:
@@ -96,9 +93,7 @@ class SpeedySpeech(nn.Module):
         """
         attn_mask = torch.unsqueeze(x_mask, -1) * torch.unsqueeze(y_mask, 2)
         attn = generate_path(dr, attn_mask.squeeze(1)).to(en.dtype)
-        o_en_ex = torch.matmul(
-            attn.squeeze(1).transpose(1, 2), en.transpose(1,
-                                                          2)).transpose(1, 2)
+        o_en_ex = torch.matmul(attn.squeeze(1).transpose(1, 2), en.transpose(1, 2)).transpose(1, 2)
         return o_en_ex, attn
 
     def format_durations(self, o_dr_log, x_mask):
@@ -115,12 +110,12 @@ class SpeedySpeech(nn.Module):
 
     def _sum_speaker_embedding(self, x, g):
         # project g to decoder dim.
-        if hasattr(self, 'proj_g'):
+        if hasattr(self, "proj_g"):
             g = self.proj_g(g)
         return x + g
 
     def _forward_encoder(self, x, x_lengths, g=None):
-        if hasattr(self, 'emb_g'):
+        if hasattr(self, "emb_g"):
             g = nn.functional.normalize(self.emb_g(g))  # [B, C, 1]
 
         if g is not None:
@@ -132,8 +127,7 @@ class SpeedySpeech(nn.Module):
         x_emb = torch.transpose(x_emb, 1, -1)
 
         # compute sequence masks
-        x_mask = torch.unsqueeze(sequence_mask(x_lengths, x.shape[1]),
-                                 1).to(x.dtype)
+        x_mask = torch.unsqueeze(sequence_mask(x_lengths, x.shape[1]), 1).to(x.dtype)
 
         # encoder pass
         o_en = self.encoder(x_emb, x_mask)
@@ -146,12 +140,11 @@ class SpeedySpeech(nn.Module):
         return o_en, o_en_dp, x_mask, g
 
     def _forward_decoder(self, o_en, o_en_dp, dr, x_mask, y_lengths, g):
-        y_mask = torch.unsqueeze(sequence_mask(y_lengths, None),
-                                 1).to(o_en_dp.dtype)
+        y_mask = torch.unsqueeze(sequence_mask(y_lengths, None), 1).to(o_en_dp.dtype)
         # expand o_en with durations
         o_en_ex, attn = self.expand_encoder_outputs(o_en, dr, x_mask, y_mask)
         # positional encoding
-        if hasattr(self, 'pos_encoder'):
+        if hasattr(self, "pos_encoder"):
             o_en_ex = self.pos_encoder(o_en_ex, y_mask)
         # speaker embedding
         if g is not None:
@@ -186,7 +179,7 @@ class SpeedySpeech(nn.Module):
         if x.shape[1] < 13:
             inference_padding += 13 - x.shape[1]
         # pad input to prevent dropping the last word
-        x = torch.nn.functional.pad(x, pad=(0, inference_padding), mode='constant', value=0)
+        x = torch.nn.functional.pad(x, pad=(0, inference_padding), mode="constant", value=0)
         o_en, o_en_dp, x_mask, g = self._forward_encoder(x, x_lengths, g)
         # duration predictor pass
         o_dr_log = self.duration_predictor(o_en_dp.detach(), x_mask)
@@ -195,9 +188,11 @@ class SpeedySpeech(nn.Module):
         o_de, attn = self._forward_decoder(o_en, o_en_dp, o_dr, x_mask, y_lengths, g=g)
         return o_de, attn
 
-    def load_checkpoint(self, config, checkpoint_path, eval=False):  # pylint: disable=unused-argument, redefined-builtin
-        state = torch.load(checkpoint_path, map_location=torch.device('cpu'))
-        self.load_state_dict(state['model'])
+    def load_checkpoint(
+        self, config, checkpoint_path, eval=False
+    ):  # pylint: disable=unused-argument, redefined-builtin
+        state = torch.load(checkpoint_path, map_location=torch.device("cpu"))
+        self.load_state_dict(state["model"])
         if eval:
             self.eval()
             assert not self.training
