@@ -1,22 +1,25 @@
-import os
-import re
 import json
-import yaml
+import os
 import pickle as pickle_tts
+import re
 from shutil import copyfile
 
+import yaml
+
 
 class RenamingUnpickler(pickle_tts.Unpickler):
     """Overload default pickler to solve module renaming problem"""
+
     def find_class(self, module, name):
-        return super().find_class(module.replace('mozilla_voice_tts', 'TTS'), name)
+        return super().find_class(module.replace("mozilla_voice_tts", "TTS"), name)
 
 
 class AttrDict(dict):
     """A custom dict which converts dict keys
     to class attributes"""
+
     def __init__(self, *args, **kwargs):
-        super(AttrDict, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.__dict__ = self
 
 
@@ -25,11 +28,12 @@ def read_json_with_comments(json_path):
     with open(json_path, "r", encoding="utf-8") as f:
         input_str = f.read()
     # handle comments
-    input_str = re.sub(r'\\\n', '', input_str)
-    input_str = re.sub(r'//.*\n', '\n', input_str)
+    input_str = re.sub(r"\\\n", "", input_str)
+    input_str = re.sub(r"//.*\n", "\n", input_str)
     data = json.loads(input_str)
     return data
 
+
 def load_config(config_path: str) -> AttrDict:
     """Load config files and discard comments
 
@@ -60,7 +64,7 @@ def copy_model_files(c, config_file, out_path, new_fields):
             in the config file.
     """
     # copy config.json
-    copy_config_path = os.path.join(out_path, 'config.json')
+    copy_config_path = os.path.join(out_path, "config.json")
     config_lines = open(config_file, "r", encoding="utf-8").readlines()
     # add extra information fields
     for key, value in new_fields.items():
@@ -69,11 +73,14 @@ def copy_model_files(c, config_file, out_path, new_fields):
         else:
             new_line = '"{}":{},\n'.format(key, json.dumps(value, ensure_ascii=False))
         config_lines.insert(1, new_line)
-    config_out_file = open(copy_config_path, "w")
+    config_out_file = open(copy_config_path, "w", encoding="utf-8")
     config_out_file.writelines(config_lines)
     config_out_file.close()
     # copy model stats file if available
-    if c.audio['stats_path'] is not None:
-        copy_stats_path = os.path.join(out_path, 'scale_stats.npy')
+    if c.audio["stats_path"] is not None:
+        copy_stats_path = os.path.join(out_path, "scale_stats.npy")
         if not os.path.exists(copy_stats_path):
-            copyfile(c.audio['stats_path'], copy_stats_path, )
+            copyfile(
+                c.audio["stats_path"],
+                copy_stats_path,
+            )
